==> haskell-data-clist-0.1.2.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-clist
version:              0.1.2.3
visibility:           public
id:                   data-clist-0.1.2.3-C6yKOz11NxFKcUMcJ5uBHt
key:                  data-clist-0.1.2.3-C6yKOz11NxFKcUMcJ5uBHt
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  acee4bb71a6c0799908ea5fdb7dcf1ca
exposed:              True
exposed-modules:      Data.CircularList
import-dirs:          /usr/lib/ghc-8.10.1/site-local/data-clist-0.1.2.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/data-clist-0.1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/data-clist-0.1.2.3
hs-libraries:         HSdata-clist-0.1.2.3-C6yKOz11NxFKcUMcJ5uBHt
depends:
    QuickCheck-2.14-5tfUQcu8WNWFLPB2la5565 base-4.14.0.0
    deepseq-1.4.4.0

haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-clist-0.1.2.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-clist
version:              0.1.2.3
visibility:           public
id:                   data-clist-0.1.2.3-8G3jNFtNGsrH7ztNyvmgPy
key:                  data-clist-0.1.2.3-8G3jNFtNGsrH7ztNyvmgPy
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  7e159c1d198901c72eb967ef189acbb1
exposed:              True
exposed-modules:      Data.CircularList
import-dirs:          /usr/lib/ghc-8.10.1/site-local/data-clist-0.1.2.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/data-clist-0.1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/data-clist-0.1.2.3
hs-libraries:         HSdata-clist-0.1.2.3-8G3jNFtNGsrH7ztNyvmgPy
depends:
    QuickCheck-2.14-ApktXbIbv818f03OoLosyK base-4.14.0.0
    deepseq-1.4.4.0

haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
